@@ -242,6 +242,10 @@ def fields_to_sql(field, default_tables={}, use_as=False) -> str:
         if field in default_tables.keys():
             # Set the table
             table = default_tables[field]
+            # Samples fields are managed differently from JOIN... Skip it
+            if table == "samples":
+                return f"`{field}`"
+
         else:
             # Unknown table, just return the field
             return f"`{field}`"
@@ -293,7 +297,7 @@ def filters_to_sql(filters, default_tables={}):
                 except ValueError:
                     pass
 
-            elif operator == "IS" and value == "NULL":
+            elif (operator == "IS" or operator == "IS NOT") and value == "NULL":
                 value = f"NULL"
 
             elif isinstance(value, str):
@@ -368,7 +372,7 @@ def filters_to_vql(filters):
                 except ValueError:
                     pass
 
-            elif operator == "IS" and value == "NULL":
+            elif (operator == "IS" or operator == "IS NOT") and value == "NULL":
                 value = f"NULL"
 
             elif isinstance(value, str):
