@@ -1945,12 +1945,13 @@ class FiltersEditorWidget(plugin.PluginWidget):
     #         self.combo.addItem(filter_name, vql_obj["filters"])
 
     def on_refresh(self):
-        """Overrided"""
+
         if self.filters == self.mainwindow.state.filters:
             # No change in filters = no refresh
             return
 
-        # Filters changed: Update UserRole of default filter and select it
+        self.model.clear()
+        self.model.filters = self.mainwindow.state.filters
 
         self.refresh_buttons()
         self._update_view_geometry()
@@ -1990,6 +1991,8 @@ class FiltersEditorWidget(plugin.PluginWidget):
 
         self.combo.clear()
 
+        print("===LOAD Combo")
+
         folder = QDir(self.filter_path)
         for index, file_info in enumerate(
             folder.entryInfoList(["*.filter.json"], QDir.Files)
@@ -2056,7 +2059,7 @@ class FiltersEditorWidget(plugin.PluginWidget):
         msgBox.setStandardButtons(QMessageBox.Save | QMessageBox.Discard)
         msgBox.setDefaultButton(QMessageBox.Save)
 
-        if msgBox.exec_():
+        if msgBox.exec_() == QMessageBox.Save:
             filename = self.combo.currentData()
             if os.path.exists(filename):
                 self.model.to_json(filename)
@@ -2084,10 +2087,10 @@ class FiltersEditorWidget(plugin.PluginWidget):
         msgBox = QMessageBox()
         msgBox.setText(f"Remove {filename}")
         msgBox.setInformativeText("Do you want to remove this file ?")
-        msgBox.setStandardButtons(QMessageBox.Save | QMessageBox.Discard)
-        msgBox.setDefaultButton(QMessageBox.Save)
+        msgBox.setStandardButtons(QMessageBox.Yes | QMessageBox.No)
+        msgBox.setDefaultButton(QMessageBox.No)
 
-        if msgBox.exec():
+        if msgBox.exec() == QMessageBox.Yes:
             if os.path.exists(filename):
                 os.remove(filename)
                 self.model.clear()
