@@ -12,14 +12,187 @@ from PySide2.QtWidgets import *
 from PySide2.QtGui import QFont
 
 # Custom imports
-from cutevariant.gui.ficon import FIcon
+from cutevariant.gui import FIcon, style
 from cutevariant.core import sql, get_sql_connection
 from cutevariant.gui.plugin import PluginWidget
 from cutevariant import commons as cm
 
+from cutevariant.gui.widgets import DictWidget
+
 LOGGER = cm.logger()
 
 
+class EditPanel(QFrame):
+    """Edit Panel 
+    
+    A panel box to edit a variant 
+
+    get_data: returned updated variant with favorite, comment and classification 
+    set_data: Fill the formular a variant  
+
+    """
+
+    # A signal emit when save button is pressed
+    saved = Signal()
+
+    _form_changed = Signal()
+
+    def __init__(self, parent=None):
+        super().__init__(parent)
+
+        # Create fav button
+        self.fav_button = QToolButton()
+        self.fav_button.setCheckable(True)
+        self.fav_button.setAutoRaise(True)
+        self.fav_button.clicked.connect(self._form_changed)
+        icon = QIcon()
+        icon.addPixmap(FIcon(0xF00C3).pixmap(32, 32), QIcon.Normal, QIcon.Off)
+        icon.addPixmap(FIcon(0xF00C0).pixmap(32, 32), QIcon.Normal, QIcon.On)
+        self.fav_button.setIcon(icon)
+
+        # Create classification combobox
+        self.class_edit = QComboBox()
+        self.class_edit.setFrame(False)
+        self.class_edit.currentIndexChanged.connect(self._form_changed)
+
+        for key in style.CLASSIFICATION:
+            self.class_edit.addItem(
+                FIcon(
+                    style.CLASSIFICATION[key]["icon"],
+                    style.CLASSIFICATION[key]["color"],
+                ),
+                style.CLASSIFICATION[key]["name"],
+            )
+
+        # Create comment form . This is a stack widget with a PlainText editor
+        # and a Markdown preview as QTextBrowser
+
+        self.comment_edit = QPlainTextEdit()
+        self.comment_edit.setPlaceholderText("Write a comment in markdown ...")
+        self.comment_edit.textChanged.connect(self._form_changed)
+
+        self.comment_preview = QTextBrowser()
+        self.comment_preview.setPlaceholderText("Press edit to add a comment ...")
+        self.comment_preview.setAlignment(Qt.AlignTop | Qt.AlignLeft)
+        self.comment_preview.setOpenExternalLinks(True)
+        self.comment_preview.setFrameStyle(QFrame.NoFrame)
+
+        # Create stacked
+        self.stack = QStackedWidget()
+        self.stack.addWidget(self.comment_edit)
+        self.stack.addWidget(self.comment_preview)
+        self.stack.setCurrentIndex(1)
+
+        # Build layout
+        self.setFrameShape(QFrame.StyledPanel)
+
+        # header  layout
+        title_layout = QHBoxLayout()
+        title_layout.addWidget(self.class_edit)
+        title_layout.addWidget(self.fav_button)
+
+        # Button layout
+        self.switch_button = QPushButton(self.tr("Edit comment..."))
+        self.switch_button.setFlat(True)
+        self.save_button = QPushButton(self.tr("Save"))
+        self.save_button.setFlat(True)
+        bar_layout = QHBoxLayout()
+        bar_layout.addWidget(self.switch_button)
+        bar_layout.addStretch()
+        bar_layout.addWidget(self.save_button)
+
+        # Main layout
+        v_layout = QVBoxLayout()
+        v_layout.addLayout(title_layout)
+        v_layout.addWidget(self.stack)
+        v_layout.addLayout(bar_layout)
+        self.setLayout(v_layout)
+
+        # Create connection
+        self.switch_button.clicked.connect(self.switch_mode)
+        self.save_button.clicked.connect(self._on_save)
+        self._form_changed.connect(lambda: self.save_button.setEnabled(True))
+
+    def switch_mode(self):
+        """Switch comment mode between editable and previewer 
+        """
+        if self.stack.currentWidget() == self.comment_edit:
+            self.stack.setCurrentIndex(1)
+            self.comment_preview.setMarkdown(str(self.comment_edit.toPlainText()))
+            self.switch_button.setText(self.tr("Edit comment..."))
+        else:
+            self.stack.setCurrentIndex(0)
+            self.switch_button.setText(self.tr("Preview comment..."))
+
+    def _on_save(self):
+        """ private slot reacting when save_button is pressed """
+
+        if self.stack.currentWidget() == self.comment_edit:
+            self.switch_mode()
+        self.saved.emit()
+        self.save_button.setEnabled(False)
+
+    def set_text(self, text: str):
+        """Set comment 
+        
+        Args:
+            text (str): Description
+        
+        """
+        if text is None:
+            self.clear()
+            return
+
+        self.comment_edit.setPlainText(str(text))
+        try:
+            self.comment_preview.setMarkdown(str(text))
+        except AttributeError:
+            # Fallback Qt 5.14-
+            self.comment_preview.setPlainText(str(text))
+
+    def clear(self):
+        """Clear comment 
+        """
+        self.comment_edit.clear()
+        self.comment_preview.clear()
+
+    def set_data(self, variant: dict):
+        """Set Form with variant data
+
+        Args:
+            variant (dict): 
+            
+        Exemples:            
+            w.set_data({"favorite": 1, "comment":'salut', "classification":4})
+        """
+
+        self.clear()
+        if "classification" in variant:
+            self.class_edit.setCurrentIndex(variant["classification"])
+
+        if "comment" in variant:
+            self.set_text(variant["comment"])
+
+        if "favorite" in variant:
+            self.fav_button.setChecked(
+                Qt.Checked if variant["favorite"] else Qt.Unchecked
+            )
+
+        self.save_button.setEnabled(False)
+
+    def get_data(self) -> dict:
+        """Get variant data from Form input 
+        
+        Returns:
+            dict: variant updated data
+        """
+        return {
+            "classification": self.class_edit.currentIndex(),
+            "comment": self.comment_edit.toPlainText(),
+            "favorite": int(self.fav_button.isChecked()),
+        }
+
+
 class VariantInfoWidget(PluginWidget):
     """Plugin to show all annotations of a selected variant"""
 
@@ -37,21 +210,21 @@ class VariantInfoWidget(PluginWidget):
         self.toolbar = QToolBar()
         self.toolbar.setIconSize(QSize(16, 16))
 
+        # Build comments tab
+        self.edit_panel = EditPanel()
+        self.edit_panel.saved.connect(self.on_save_variant)
+        self.view.addTab(self.edit_panel, self.tr("User"))
+
         # Build variant tab
-        self.variant_view = QTreeWidget()
-        self.variant_view.setColumnCount(2)
-        self.variant_view.setAlternatingRowColors(True)
-        # self.variant_view.setHeaderLabels(["Field", "Value"])
-        self.variant_view.header().setVisible(False)
+        self.variant_view = DictWidget()
+        self.variant_view.set_header_visible(True)
+
         self.view.addTab(self.variant_view, self.tr("Variant"))
 
         # Build transcript tab
         self.transcript_combo = QComboBox()
-        self.transcript_view = QTreeWidget()
-        self.transcript_view.setColumnCount(2)
-        self.transcript_view.setAlternatingRowColors(True)
-        # self.transcript_view.setHeaderLabels(["Field", "Value"])
-        self.transcript_view.header().setVisible(False)
+        self.transcript_view = DictWidget()
+        self.transcript_view.set_header_visible(True)
         tx_layout = QVBoxLayout()
         tx_layout.addWidget(self.transcript_combo)
         tx_layout.addWidget(self.transcript_view)
@@ -62,11 +235,9 @@ class VariantInfoWidget(PluginWidget):
 
         # Build Samples tab
         self.sample_combo = QComboBox()
-        self.sample_view = QTreeWidget()
-        self.sample_view.setAlternatingRowColors(True)
-        self.sample_view.setColumnCount(2)
-        # self.sample_view.setHeaderLabels(["Field", "Value"])
-        self.sample_view.header().setVisible(False)
+        self.sample_view = DictWidget()
+        self.sample_view.set_header_visible(True)
+
         tx_layout = QVBoxLayout()
         tx_layout.addWidget(self.sample_combo)
         tx_layout.addWidget(self.sample_view)
@@ -80,24 +251,6 @@ class VariantInfoWidget(PluginWidget):
         self.genotype_view.setIconSize(QSize(20, 20))
         self.view.addTab(self.genotype_view, self.tr("Genotypes"))
 
-        # Build comments tab
-        # Build Editor
-        # TODO: edit comment on variant is disabled
-        self.comment_input = QTextBrowser()
-        self.comment_input.setAlignment(Qt.AlignTop | Qt.AlignLeft)
-        self.comment_input.setOpenExternalLinks(True)
-        self.editor = QWidget()
-        self.editor_layout = QVBoxLayout()
-        # Save comment functionality
-        # sub_edit_layout = QFormLayout()
-        # editor_layout.setRowWrapPolicy(QFormLayout.WrapAllRows)
-        # sub_edit_layout.addWidget(self.comment_input)
-        # sub_edit_layout.addWidget(self.save_button)
-        # self.save_button.clicked.connect(self.on_save_clicked)
-        self.editor_layout.addWidget(self.comment_input)
-        self.editor.setLayout(self.editor_layout)
-        self.view.addTab(self.editor, self.tr("Comments"))
-
         v_layout = QVBoxLayout()
         v_layout.setContentsMargins(0, 0, 0, 0)
         v_layout.addWidget(self.view)
@@ -127,7 +280,25 @@ class VariantInfoWidget(PluginWidget):
         self.transcript_view.clear()
         self.sample_view.clear()
         self.genotype_view.clear()
-        self.comment_input.clear()
+        self.edit_panel.clear()
+
+    def on_save_variant(self):
+
+        # if view is visible
+        if "variant_view" in self.mainwindow.plugins:
+            variant_view = self.mainwindow.plugins["variant_view"]
+
+            update_data = self.edit_panel.get_data()
+
+            index = variant_view.main_right_pane.view.currentIndex()
+            variant_view.main_right_pane.model.update_variant(index.row(), update_data)
+
+            # variant_view.main_right_pane.model.update_variant(index.row(), update_data)
+
+        else:
+            # TODO BUT UNNECESSARY because we always have a variant_viex ...
+            # Save directly in database ?
+            pass
 
     def on_open_project(self, conn):
         self.conn = conn
@@ -154,13 +325,24 @@ class VariantInfoWidget(PluginWidget):
         variant_id = self.current_variant["id"]
 
         # Populate variant
-        self.populate_tree_widget(
-            self.variant_view, sql.get_one_variant(self.conn, variant_id)
+        data = dict(
+            [
+                (k, v)
+                for k, v in sql.get_one_variant(self.conn, variant_id).items()
+                if k not in ("variant_id", "sample_id", "annotations", "samples")
+            ]
         )
+        self.variant_view.set_dict(data)
+
+        self.edit_panel.set_data(data)
+
+        title = "{chr}:{pos} {ref}>{alt}".format(**data)
+        # self.parent().setWindowTitle(title)
 
         # Populate annotations
         self.transcript_combo.blockSignals(True)
         self.transcript_combo.clear()
+
         for annotation in sql.get_annotations(self.conn, variant_id):
             if "transcript" in annotation:
                 self.transcript_combo.addItem(annotation["transcript"], annotation)
@@ -198,7 +380,7 @@ class VariantInfoWidget(PluginWidget):
         Fill fields & values for selected transcript.
         """
         annotations = self.transcript_combo.currentData()
-        self.populate_tree_widget(self.transcript_view, annotations)
+        self.transcript_view.set_dict(annotations)
 
     @Slot()
     def on_sample_changed(self):
@@ -209,59 +391,10 @@ class VariantInfoWidget(PluginWidget):
         sample_id = self.sample_combo.currentData()
         variant_id = self.current_variant["id"]
 
-        self.populate_tree_widget(
-            self.sample_view,
-            sql.get_sample_annotations(self.conn, variant_id, sample_id),
+        self.sample_view.set_dict(
+            sql.get_sample_annotations(self.conn, variant_id, sample_id)
         )
 
-    def populate_tree_widget(self, treewidget, data):
-        """Add the content of data to the given treewidget
-
-        Args:
-            treewidget(QTreeWidget): A widget in a tab of the main view of this
-                plugin: Variant, Transcripts, Samples.
-            data(dict): Dictionary with field names as keys and content as values.
-                Fields will be displayed in the left column; Values will be
-                displayed in the right column.
-        """
-        font = QFont()
-        font.setBold(True)
-        treewidget.clear()
-        if not data:
-            return
-
-        for key, value in data.items():
-            if (
-                key in ("variant_id", "sample_id", "annotations", "samples")
-                and LOGGER.getEffectiveLevel() != DEBUG
-            ):
-                # "variant_id", "sample_id": For Samples tab
-                # "annotations", "samples": For useless keys returned by get_one_variant
-                # "id": For Variant tab
-                continue
-
-            if key == "comment":
-                # For Variant tab
-                try:
-                    self.comment_input.setMarkdown(str(value))
-                except AttributeError:
-                    # Fallback Qt 5.14-
-                    self.comment_input.setPlainText(str(value))
-
-            item = QTreeWidgetItem()
-            item.setText(0, key)
-            item.setFont(0, font)
-            item.setText(1, str(value))
-
-            # Tooltips on header AND field => easier for user
-            tooltip = self.fields_descriptions.get(key, "")
-            item.setToolTip(0, tooltip)
-            item.setToolTip(1, tooltip)
-
-            treewidget.addTopLevelItem(item)
-
-        treewidget.resizeColumnToContents(0)
-
     # @Slot()
     # def on_save_clicked(self):
     #     """Save button
