@@ -5,12 +5,12 @@ from PySide2.QtWidgets import *
 
 # Custom imports
 from cutevariant.gui.plugin import PluginSettingsWidget
-from cutevariant.gui.settings import BaseWidget
+from cutevariant.gui.settings import AbstractSettingsWidget
 from cutevariant.gui import FIcon
 import cutevariant.commons as cm
 
 
-class LinkSettings(BaseWidget):
+class LinkSettings(AbstractSettingsWidget):
     def __init__(self):
         super().__init__()
         self.setWindowTitle(self.tr("Cross databases links"))
@@ -55,26 +55,30 @@ class LinkSettings(BaseWidget):
         self.remove_button.clicked.connect(self.remove_item)
 
     def save(self):
-        """Override from BaseWidget"""
-        settings = QSettings()
+        """Override from PageWidget"""
+        settings = self.create_settings()
+
         # Bug from Pyside2.QSettings which don't return boolean
-        settings.remove("plugins/variant_view/links")
-        settings.beginWriteArray("plugins/variant_view/links")
+        settings.remove("links")
+        settings.beginWriteArray("links")
         for i in range(self.view.count()):
             settings.setArrayIndex(i)
             item = self.view.item(i)
             name = item.text()
             url = item.data(Qt.UserRole)
-            is_default = int(item.data(Qt.UserRole + 1))
+            is_default = bool(item.data(Qt.UserRole + 1))
+            is_browser = bool(item.data(Qt.UserRole + 2))
             settings.setValue("name", name)
             settings.setValue("url", url)
             settings.setValue("is_default", is_default)
+            settings.setValue("is_browser", is_browser)
+
         settings.endArray()
 
     def load(self):
-        """Override from BaseWidget"""
-        settings = QSettings()
-        size = settings.beginReadArray("plugins/variant_view/links")
+        """Override from PageWidget"""
+        settings = self.create_settings()
+        size = settings.beginReadArray("links")
         self.view.clear()
 
         #  If no links available, load default one
@@ -87,17 +91,23 @@ class LinkSettings(BaseWidget):
             url = settings.value("url")
 
             # Bug from Pyside2.QSettings which don't return boolean
-            is_default = bool(int(settings.value("is_default")))
-            self.add_list_widget_item(name, url, is_default)
+            is_default = settings.value("is_default", False, type=bool)
+            is_browser = settings.value("is_browser", False, type=bool)
+
+            self.add_list_widget_item(name, url, is_default, is_browser)
+
         settings.endArray()
 
-    def add_list_widget_item(self, db_name: str, url: str, is_default=False):
+    def add_list_widget_item(
+        self, db_name: str, url: str, is_default=False, is_browser=False
+    ):
         """Add an item to the QListWidget of the current view"""
         # Key is the name of the database, value is its url
         item = QListWidgetItem(db_name)
         item.setIcon(FIcon(0xF0866))
         item.setData(Qt.UserRole, str(url))  #  UserRole = Link
         item.setData(Qt.UserRole + 1, bool(is_default))  # UserRole+1 = is default link
+        item.setData(Qt.UserRole + 2, bool(is_browser))  # UserRole+1 = is default link
         item.setToolTip(str(url))
 
         font = item.font()
@@ -106,44 +116,74 @@ class LinkSettings(BaseWidget):
 
         self.view.addItem(item)
 
-    def edit_list_widget_item(self, item: QListWidgetItem, db_name: str, url: str):
+    def edit_list_widget_item(
+        self,
+        item: QListWidgetItem,
+        db_name: str,
+        url: str,
+        is_default=False,
+        is_browser=False,
+    ):
         """Modify the given item"""
         item.setText(db_name)
         item.setData(Qt.UserRole, url)
+        item.setData(Qt.UserRole + 1, is_default)
+        item.setData(Qt.UserRole + 2, is_browser)
 
     def add_url(self, item=None):
         """Allow the user to insert and save custom database URL"""
         # Display dialog box to let the user enter it's own url
         dialog = QDialog()
-        title = QLabel(self.tr("Example: http://url_with_columns{chr}{pos}{ref}{alt}"))
+        title = QLabel(
+            self.tr(
+                """Create a link using variant field as place holder.
+For instance, to open UCSC genom browser use :\n
+https://genome.ucsc.edu/cgi-bin/hgTracks?db=hg19&position={chr}:{pos}
+            """
+            )
+        )
         name = QLineEdit()
         url = QLineEdit()
+        browser = QCheckBox(
+            self.tr("Keep this box unchecked if you only want a http request ")
+        )
         buttons = QDialogButtonBox(QDialogButtonBox.Ok | QDialogButtonBox.Cancel)
         buttons.accepted.connect(dialog.accept)
         buttons.rejected.connect(dialog.reject)
+
         layout = QFormLayout()
-        layout.addWidget(title)
         layout.addRow(self.tr("Name"), name)
         layout.addRow(self.tr("Url mask"), url)
+        layout.addRow(self.tr("Open in browser"), browser)
         layout.addWidget(buttons)
 
-        dialog.setLayout(layout)
+        main_layout = QVBoxLayout()
+        main_layout.addWidget(title)
+        main_layout.addLayout(layout)
+
+        dialog.setLayout(main_layout)
 
         if item:
             # Called by itemDoubleClicked or edit_item
             # Fill forms with item data
             name.setText(item.text())
             url.setText(item.data(Qt.UserRole))
+            is_browser = Qt.Checked if item.data(Qt.UserRole + 2) == 1 else Qt.Unchecked
+            browser.setChecked(is_browser)
 
         # Also do a minimal check on the data inserted
         if dialog.exec_() == QDialog.Accepted and name.text() and url.text():
 
             if item:
                 # Edit the current item in the list
-                self.edit_list_widget_item(item, name.text(), url.text())
+                self.edit_list_widget_item(
+                    item, name.text(), url.text(), False, bool(browser.checkState())
+                )
             else:
                 # Add the item to the list
-                self.add_list_widget_item(name.text(), url.text())
+                self.add_list_widget_item(
+                    name.text(), url.text(), False, bool(browser.checkState())
+                )
 
             # Save the item in settings
             # (Here to limit the friction with Save all button)
@@ -189,12 +229,32 @@ class LinkSettings(BaseWidget):
         for row in range(self.view.count()):
             item = self.view.item(row)
             font = item.font()
-            is_default = True if item == current_item else False
+            is_default = True if item is current_item else False
             item.setData(Qt.UserRole + 1, is_default)
             font.setBold(is_default)
             item.setFont(font)
 
 
+class MemorySettings(AbstractSettingsWidget):
+    def __init__(self):
+        super().__init__()
+        self.setWindowTitle(self.tr("Memory"))
+        self.setWindowIcon(FIcon(0xF070F))
+
+        layout = QFormLayout()
+        self.spinbox = QSpinBox()
+        self.spinbox.setRange(0, 100000)
+        layout.addRow(self.tr("Cache size"), self.spinbox)
+
+    def save(self):
+        """ overload """
+        pass
+
+    def load(self):
+        """ load """
+        pass
+
+
 class VariantViewSettingsWidget(PluginSettingsWidget):
     """Instantiated plugin in the settings panel of Cutevariant
 
@@ -208,4 +268,5 @@ class VariantViewSettingsWidget(PluginSettingsWidget):
         super().__init__(parent)
         self.setWindowIcon(FIcon(0xF035C))
         self.setWindowTitle("Variant view")
-        self.add_settings_widget(LinkSettings())
+        # self.add_settings_widget(MemorySettings())
+        self.add_page(LinkSettings())
